@@ -57,13 +57,13 @@ class WeatherChart:
 			labels.append( item_key )
 			weather_readings.append( forecast[ item_key ]['temp'] )
 		
-		qc.config = self._get_forecast_chart_image_config( labels, weather_readings)
+		qc.config = self._get_forecast_chart_image_config( loc_string, labels, weather_readings)
 		# print(qc.config)
 		# print( ) 	#Print out the chart URL
 		if output_file: qc.to_file( output_file )	#Save to a file
 		return qc.get_short_url() 
 	
-	def _get_forecast_chart_image_config(self, labels, weather_readings ):
+	def _get_forecast_chart_image_config(self, loc_string, labels, weather_readings ):
 		min, max = self._get_min_max_tick_item( weather_readings, 2)
 
 		return { 'type': 'line',
